# UM-Bridge

UM-Bridge (the UQ and Model Bridge) is a unified interface for numerical models that is accessible from virtually any programming language or framework. It is primarily intended for coupling advanced models (e.g. simulations of complex physical processes) to advanced statistical or optimization methods.

Documentation including tutorials and UQ benchmark library can be found here: [Documentation](https://um-bridge-benchmarks.readthedocs.io/en/docs/).

Instructions for contacting the team, bug reports and contributions can be found in [CONTRIBUTING.md](CONTRIBUTING.md).
